Learn R Programming

provolleyballr (version 0.1.0)

au_stats: Extract Data from Athletes Unlimited Volleyball Website

Description

This function scrapes player season statistics for Athletes Unlimited Volleyball (AU) players from the official AU website https://auprosports.com/volleyball/.

Usage

au_stats(year = NULL, stored = TRUE)

Value

A tibble containing team player season statistics.

Player data include: year, rank, player, points, sets_played, kills, kills_per_set, attack_errors, attack_attempts, kill_percentage, assists, assists_per_set, setting_errors, service_aces, service_errors, service_aces_per_set, total_reception_attempts, reception_errors, positive_reception_percentage, digs, digs_per_set, blocks, blocks_per_set, block_assists, good_receptions

Arguments

year

A numeric value specifying the year for which to retrieve statistics. Must be 2024 or later for LOVB or MLV and 2021 or later for AU.

stored

A logical specifying whether to use stored data for previous years (TRUE is default) or force the function to scrape the website (FALSE)

See Also

Other statistics functions: get_stats(), group_stats(), lovb_stats(), mlv_stats()

Examples

Run this code
if (FALSE) { # interactive()
# Get 2025 player statistics
au_stats(year = 2025)
}

Run the code above in your browser using DataLab