Learn R Programming

provolleyballr (version 0.1.0)

au_player_data: Athletes Unlimited Individual Player Statistics

Description

A dataset containing individual player season statistics for Athletes Unlimited (UA) players for the 2021-2025 seasons.

Usage

au_player_data

Arguments

Format

A data frame with 220 rows and 25 variables:

year

Season year

rank

Player rank

player

Player name

points

Total points achieved

sets_played

Sets played

kills

Kills - successful attacks

kills_per_set

Kills per set

attack_errors

Attack Errors

attack_attempts

Total attack attempts

kill_percentage

Kill percentage

assists

Assists - sets that lead directly to a kill

assists_per_set

Assists per set

setting_errors

Setting errors

service_aces

Service Aces - serves that result directly in a point

service_errors

Service errors

service_aces_per_set

Service aces per set

total_reception_attempts

Total reception attempts

reception_errors

Reception errors

positive_reception_percentage

Percentage of reception attempts that are either positive or perfect

digs

Digs - successful defensive plays

digs_per_set

Digs per set

blocks

Blocks - successful defensive plays at the net

blocks_per_set

Blocks per set

block_assists

Block assists - two- or three-person blocks

good_receptions

Number of positive receptions

See Also

Other datasets: lovb_player_data, lovb_team_data, lovb_teams, mlv_player_data, mlv_team_data, mlv_teams

Examples

Run this code
head(au_player_data)

Run the code above in your browser using DataLab