A dataset containing individual player season statistics for Athletes Unlimited (UA) players for the 2021-2025 seasons.
au_player_dataA data frame with 220 rows and 25 variables:
Season year
Player rank
Player name
Total points achieved
Sets played
Kills - successful attacks
Kills per set
Attack Errors
Total attack attempts
Kill percentage
Assists - sets that lead directly to a kill
Assists per set
Setting errors
Service Aces - serves that result directly in a point
Service errors
Service aces per set
Total reception attempts
Reception errors
Percentage of reception attempts that are either positive or perfect
Digs - successful defensive plays
Digs per set
Blocks - successful defensive plays at the net
Blocks per set
Block assists - two- or three-person blocks
Number of positive receptions
Other datasets:
lovb_player_data,
lovb_team_data,
lovb_teams,
mlv_player_data,
mlv_team_data,
mlv_teams