Learn R Programming

provolleyballr (version 0.1.0)

get_stats: Extract Data from US Women's Professional Volleyball Websites

Description

This function scrapes team match-by-match and player season statistics for Athletes Unlimited (UA), League One Volleyball (LOVB), or Major League Volleyball (MLV) players and teams from the official websites.

Usage

get_stats(league = NULL, team = NULL, year = NULL, level = NULL, stored = TRUE)

Value

A tibble containing team match-by-match or player season statistics.

Arguments

league

A character string specifying which league to retrieve. Must be "AU", "LOVB" or "MLV".

team

A character string specifying the team name or city. Accepts city names (e.g., "Omaha", "Atlanta") or variations like "Indianapolis" (converted to "Indy") and "Las Vegas" (converted to "Vegas"). Must match one of the valid LOVB or MLV team cities. AU has no teams.

year

A numeric value specifying the year for which to retrieve statistics. Must be 2024 or later for LOVB or MLV and 2021 or later for AU.

level

A character string specifying whether to extract the "team" or individual "player" statistics. AU has no team statistics.

stored

A logical specifying whether to use stored data for previous years (TRUE is default) or force the function to scrape the website (FALSE)

See Also

Other statistics functions: au_stats(), group_stats(), lovb_stats(), mlv_stats()

Examples

Run this code
if (FALSE) { # interactive()
# Get Omaha Supernovas 2024 match statistics
get_stats(league = "AU", year = 2025)
get_stats(league = "LOVB", team = "Austin", year = 2025, level = "team")
get_stats(league = "LOVB", team = "Austin", year = 2025, level = "player")
get_stats(league = "MLV", team = "Omaha", year = 2024, level = "team")
get_stats(league = "MLV", team = "Omaha", year = 2024, level = "player")
}

Run the code above in your browser using DataLab