A dataset containing information about League One Volleyball (LOVB) teams,
including team names, URL slugs, and first year used for web scraping.
Usage
lovb_teams
Arguments
Format
A data frame with 8 rows and 5 variables:
name
Team city name
slug
URL slug used in LOVB website URLs
first_year
Year that team started in LOVB
Details
This dataset is used internally by the package functions to map
user-provided team names to the appropriate URL slugs needed for web scraping
the LOVB website.
See Also
Other datasets:
au_player_data,
lovb_player_data,
lovb_team_data,
mlv_player_data,
mlv_team_data,
mlv_teams