A dataset containing information about Major League Volleyball (MLV) teams,
including team names, cities, mascots, URL slugs, and first year used for web scraping.
Usage
mlv_teams
Arguments
Format
A data frame with 8 rows and 5 variables:
city
Team city name
mascot
Team mascot name
name
Full team name (city + mascot)
slug
URL slug used in MLV website URLs
first_year
Year that team started in MLV
Details
This dataset is used internally by the package functions to map
user-provided team names to the appropriate URL slugs needed for web scraping
the MLV website.
See Also
Other datasets:
au_player_data,
lovb_player_data,
lovb_team_data,
lovb_teams,
mlv_player_data,
mlv_team_data